# 26/8/2020

# Antti Miettinen, Stefan Palm, Johan Dannewitz, Emma Lind, Craig R. Primmer, Atso Romakkaniemi, Johan stergren, Victoria L. Pritchard

# Article: "A large wild salmon stock shows genetic and life history differentiation within, but not between, rivers" 
# email: Antti Miettinen (antti.aj.miettinen@helsinki.fi)

setwd("File path")
#Such as:
#setwd(".../TornioKalix_Msat_Dryad/TornioKalix_Msat_Data/Data for R")

########### MAIN CODE

# This includes all the analyses done in R, except the ones in the Supplementary Material.


## 1) Genetic mixed stock analyses (MSA) using rubias

# Packages needed

library(rubias)
library(tidyverse)

######

# a) Parr self-assignment

#Read the baseline PARR data file & code repunit, collection, indiv and sample_type as characters
Reference_parr  = read.table ("Reference_parr_TK_for_Rubias.txt", header=T, skipNul=T)
#This baseline file includes parr from all sites of the Tornio-Kalix system (n = 749)

Reference_parr$repunit = as.character (Reference_parr$repunit)
Reference_parr$collection = as.character (Reference_parr$collection)
Reference_parr$indiv = as.character (Reference_parr$indiv)
Reference_parr$sample_type = as.character (Reference_parr$sample_type)

#Do the self-assignment test
sa_Reference_parr = self_assign (reference = Reference_parr, gen_start_col = 5)

#Extract the 'most likely' population of origin for each individual, 
#i.e. the one with the highest scaled likelihood out of all the possible populations
sa_Reference_parr_top = sa_Reference_parr %>% group_by(indiv) %>% top_n(1, scaled_likelihood) %>% ungroup()

#Add columns to indicate whether the parr was assigned to the correct collection site or reporting group 
#The final column enables us to count the total number of parr
sa_Reference_parr_topb = sa_Reference_parr_top %>% select (1:6) %>% 
  mutate (pop_match = ifelse(collection  == inferred_collection, 1, 0)) %>% 
  mutate (repunit_match =ifelse (repunit  == inferred_repunit, 1, 0)) %>% mutate (count =1)

#Calculate the proportion of parr that were correctly assigned to their source collection site
sa_Reference_parr_topc = sa_Reference_parr_topb %>% group_by (collection) %>% 
  summarize (proppop = (sum(pop_match)/sum(count)))

#Calculate the proportion of parr that were correctly assigned to their source reporting group (Upper or Lower)
sa_Reference_parr_topd = sa_Reference_parr_topb %>% group_by (repunit) %>% 
  summarize (proprepunit = (sum(repunit_match)/sum(count))) 

#Write collection site assignment for each individual and correct assignment results 
#at the site and reporting group level to text files
write.table (sa_Reference_parr_topb, file = "Reference_parr_popassig.txt", row.names = F, quote=F, sep= "\t")
write.table (sa_Reference_parr_topc, file = "Reference_parr_popmatch.txt", row.names = F, quote=F, sep= "\t")
write.table (sa_Reference_parr_topd, file = "Reference_parr_repunitmatch.txt", row.names = F, quote=F, sep= "\t")


#Individual reassignment results (at the reporting group level) for all of the parr in the baseline. 
#The point of this is to give a visual idea of 'how good' the method is really at 
#assigning individuals to their correct reporting group.

summary_sa = sa_Reference_parr %>% group_by (indiv, inferred_repunit) %>% summarize (Total = sum (scaled_likelihood))

summary_upper = filter (summary_sa, inferred_repunit == "Upper")

summary_upper_site = left_join (summary_upper, Reference_parr, by = "indiv") %>% select (1,2,3,5,6)

#Package needed for making Figure 5 below

library(ggplot2)

# Code for making Figure 5 below

xplot = ggplot (summary_upper_site, aes (x=collection, y=Total, colour=repunit))

xplot2 = xplot + geom_jitter(width=0.2, alpha=0.7) + theme_classic() + 
  theme(panel.grid.major.x = element_blank(), panel.grid.minor.x = element_blank()) + 
  theme(panel.grid.major.y = element_blank(), panel.grid.minor.y = element_blank()) + 
  theme(legend.position="top") + ylab("P(Upper)") + xlab("Collection site") + 
  scale_colour_discrete(name="Reporting group")

Fig5plot <- xplot2 + scale_colour_manual(name="Reporting group", values = c("#62ddbe", "#3949ac")) +
  theme(legend.text = element_text(size = 11))

Fig5plot


############

# b) Smolt mixture analyses

#Read the data file for SMOLTS & code repunit, collection, indiv and sample_type as characters
smolts_rubias  = read.table ("Smolts_TK_for_Rubias.txt", header=T, skipNul=T)

smolts_rubias$repunit = as.character (smolts_rubias$repunit)
smolts_rubias$collection = as.character (smolts_rubias$collection)
smolts_rubias$indiv = as.character (smolts_rubias$indiv)
smolts_rubias$sample_type = as.character (smolts_rubias$sample_type)

#Assign smolts to collection site & reporting group using parr as the baseline.
smolt_mix_est <- infer_mixture(reference = Reference_parr, mixture = smolts_rubias, gen_start_col = 5)

#Collect the data from the MCMC reps for each week 
#and summarize the proportion of the stock assigned to each reporting unit for each week.
#Discard the first 200 sweeps as burn-in.
trace_smolt_W1 <- smolt_mix_est$mix_prop_traces %>% filter(mixture_collection == "Week1", sweep > 200) %>% group_by(sweep, collection) %>%summarise(repprop = sum(pi))
trace_smolt_W2 <- smolt_mix_est$mix_prop_traces %>% filter(mixture_collection == "Week2", sweep > 200) %>% group_by(sweep, collection) %>%summarise(repprop = sum(pi))
trace_smolt_W3 <- smolt_mix_est$mix_prop_traces %>% filter(mixture_collection == "Week3", sweep > 200) %>% group_by(sweep, collection) %>%summarise(repprop = sum(pi))
trace_smolt_W4 <- smolt_mix_est$mix_prop_traces %>% filter(mixture_collection == "Week4", sweep > 200) %>% group_by(sweep, collection) %>%summarise(repprop = sum(pi))
trace_smolt_W5 <- smolt_mix_est$mix_prop_traces %>% filter(mixture_collection == "Week5", sweep > 200) %>% group_by(sweep, collection) %>%summarise(repprop = sum(pi))
trace_smolt_W6 <- smolt_mix_est$mix_prop_traces %>% filter(mixture_collection == "Week6", sweep > 200) %>% group_by(sweep, collection) %>%summarise(repprop = sum(pi))

#Adding a column showing what week each summary dataset was from,
#and joining them back together so we can plot all the weeks in one figure
trace_smolt_W1$Week = "Week1"
trace_smolt_W2$Week = "Week2"
trace_smolt_W3$Week = "Week3"
trace_smolt_W4$Week = "Week4"
trace_smolt_W5$Week = "Week5"
trace_smolt_W6$Week = "Week6"

trace_smolt_allweeks = bind_rows (trace_smolt_W1, trace_smolt_W2, trace_smolt_W3, trace_smolt_W4, trace_smolt_W5, trace_smolt_W6)


#Computing Credible Intervals and Mean from the Traces

#Read the data file for SMOLTS without split weeks & code repunit, collection, indiv and sample_type as characters
smolts_tracesmean  = read.table ("Smolts_TK_for_Rubias_noweeks.txt", header=T, skipNul=T)

smolts_tracesmean$repunit = as.character (smolts_tracesmean$repunit)
smolts_tracesmean$collection = as.character (smolts_tracesmean$collection)
smolts_tracesmean$indiv = as.character (smolts_tracesmean$indiv)
smolts_tracesmean$sample_type = as.character (smolts_tracesmean$sample_type)

smolt_mix_est_tracesmean <- infer_mixture(reference = Reference_parr, mixture = smolts_tracesmean, gen_start_col = 5)

trace_smolts<- smolt_mix_est_tracesmean$mix_prop_traces %>% filter(sweep > 200) %>% group_by(sweep, repunit) %>%summarise(repprop = sum(pi))
values_smolt<- trace_smolts %>% group_by(repunit) %>% summarise(loCI = quantile(repprop, probs = 0.025), hiCI = quantile(repprop, probs = 0.975), mean = mean(repprop))
values_smolt


##########

# c) Adults mixture analyses (all the steps are the same as for smolts above)

## Adults 2009

adults09_rubias  = read.table ("Adults2009_TK_for_Rubias.txt", header=T, skipNul=T)

adults09_rubias$repunit = as.character (adults09_rubias$repunit)
adults09_rubias$collection = as.character (adults09_rubias$collection)
adults09_rubias$indiv = as.character (adults09_rubias$indiv)
adults09_rubias$sample_type = as.character (adults09_rubias$sample_type)

adults09_mix_est <- infer_mixture(reference = Reference_parr, mixture = adults09_rubias, gen_start_col = 5)

trace_adults09_W1 <- adults09_mix_est$mix_prop_traces %>% filter(mixture_collection == "Week1_2", sweep > 200) %>% group_by(sweep, collection) %>%summarise(repprop = sum(pi))
trace_adults09_W2 <- adults09_mix_est$mix_prop_traces %>% filter(mixture_collection == "Week3_4", sweep > 200) %>% group_by(sweep, collection) %>%summarise(repprop = sum(pi))
trace_adults09_W3 <- adults09_mix_est$mix_prop_traces %>% filter(mixture_collection == "Week5_6", sweep > 200) %>% group_by(sweep, collection) %>%summarise(repprop = sum(pi))
trace_adults09_W4 <- adults09_mix_est$mix_prop_traces %>% filter(mixture_collection == "Week7_8", sweep > 200) %>% group_by(sweep, collection) %>%summarise(repprop = sum(pi))
trace_adults09_W5 <- adults09_mix_est$mix_prop_traces %>% filter(mixture_collection == "Week9_10", sweep > 200) %>% group_by(sweep, collection) %>%summarise(repprop = sum(pi))

trace_adults09_W1$Week = "Weeks1_2"
trace_adults09_W2$Week = "Weeks3_4"
trace_adults09_W3$Week = "Weeks5_6"
trace_adults09_W4$Week = "Weeks7_8"
trace_adults09_W5$Week = "Weeks9_10"

trace_adults09_W1_2 = bind_rows(trace_adults09_W1)
trace_adults09_W3_4 = bind_rows(trace_adults09_W2)
trace_adults09_W5_6 = bind_rows(trace_adults09_W3)
trace_adults09_W7_8 = bind_rows(trace_adults09_W4)
trace_adults09_W9_10 = bind_rows(trace_adults09_W5)

trace_adults09_allweeks = bind_rows (trace_adults09_W1, trace_adults09_W2, trace_adults09_W3, trace_adults09_W4, trace_adults09_W5)


#Computing Credible Intervals and Mean from the Traces

#Read the data file for adults 2009 without split weeks 
#& code repunit, collection, indiv and sample_type as characters
adults09_tracesmean  = read.table ("Adults2009_TK_for_Rubias_noweeks.txt", header=T, skipNul=T)

adults09_tracesmean$repunit = as.character (adults09_tracesmean$repunit)
adults09_tracesmean$collection = as.character (adults09_tracesmean$collection)
adults09_tracesmean$indiv = as.character (adults09_tracesmean$indiv)
adults09_tracesmean$sample_type = as.character (adults09_tracesmean$sample_type)

adults09_mix_est_tracesmean <- infer_mixture(reference = Reference_parr, mixture = adults09_tracesmean, gen_start_col = 5)

trace_adults09<- adults09_mix_est_tracesmean$mix_prop_traces %>% filter(sweep > 200) %>% group_by(sweep, repunit) %>%summarise(repprop = sum(pi))
values_adults09<- trace_adults09 %>% group_by(repunit) %>% summarise(loCI = quantile(repprop, probs = 0.025), hiCI = quantile(repprop, probs = 0.975), mean = mean(repprop))
values_adults09


## Adults 2010

adults10_rubias  = read.table ("Adults2010_TK_for_Rubias.txt", header=T, skipNul=T)

adults10_rubias$repunit = as.character (adults10_rubias$repunit)
adults10_rubias$collection = as.character (adults10_rubias$collection)
adults10_rubias$indiv = as.character (adults10_rubias$indiv)
adults10_rubias$sample_type = as.character (adults10_rubias$sample_type)

adults10_mix_est <- infer_mixture(reference = Reference_parr, mixture = adults10_rubias, gen_start_col = 5)

trace_adults10_W1 <- adults10_mix_est$mix_prop_traces %>% filter(mixture_collection == "Week1_2", sweep > 200) %>% group_by(sweep, collection) %>%summarise(repprop = sum(pi))
trace_adults10_W2 <- adults10_mix_est$mix_prop_traces %>% filter(mixture_collection == "Week3_4", sweep > 200) %>% group_by(sweep, collection) %>%summarise(repprop = sum(pi))
trace_adults10_W3 <- adults10_mix_est$mix_prop_traces %>% filter(mixture_collection == "Week5_6", sweep > 200) %>% group_by(sweep, collection) %>%summarise(repprop = sum(pi))
trace_adults10_W4 <- adults10_mix_est$mix_prop_traces %>% filter(mixture_collection == "Week7_8", sweep > 200) %>% group_by(sweep, collection) %>%summarise(repprop = sum(pi))
trace_adults10_W5 <- adults10_mix_est$mix_prop_traces %>% filter(mixture_collection == "Week9_10", sweep > 200) %>% group_by(sweep, collection) %>%summarise(repprop = sum(pi))

trace_adults10_W1$Week = "Weeks1_2"
trace_adults10_W2$Week = "Weeks3_4"
trace_adults10_W3$Week = "Weeks5_6"
trace_adults10_W4$Week = "Weeks7_8"
trace_adults10_W5$Week = "Weeks9_10"

trace_adults10_W1_2 = bind_rows(trace_adults10_W1)
trace_adults10_W3_4 = bind_rows(trace_adults10_W2)
trace_adults10_W5_6 = bind_rows(trace_adults10_W3)
trace_adults10_W7_8 = bind_rows(trace_adults10_W4)
trace_adults10_W9_10 = bind_rows(trace_adults10_W5)

trace_adults10_allweeks = bind_rows (trace_adults10_W1, trace_adults10_W2, trace_adults10_W3, trace_adults10_W4, trace_adults10_W5)

#Computing Credible Intervals and Mean from the Traces

#Read the data file for adults 2010 without split weeks 
#& code repunit, collection, indiv and sample_type as characters
adults10_tracesmean  = read.table ("Adults2010_TK_for_Rubias_noweeks.txt", header=T, skipNul=T)

adults10_tracesmean$repunit = as.character (adults10_tracesmean$repunit)
adults10_tracesmean$collection = as.character (adults10_tracesmean$collection)
adults10_tracesmean$indiv = as.character (adults10_tracesmean$indiv)
adults10_tracesmean$sample_type = as.character (adults10_tracesmean$sample_type)

adults10_mix_est_tracesmean <- infer_mixture(reference = Reference_parr, mixture = adults10_tracesmean, gen_start_col = 5)

trace_adults10<- adults10_mix_est_tracesmean$mix_prop_traces %>% filter(sweep > 200) %>% group_by(sweep, repunit) %>%summarise(repprop = sum(pi))
values_adults10<- trace_adults10 %>% group_by(repunit) %>% summarise(loCI = quantile(repprop, probs = 0.025), hiCI = quantile(repprop, probs = 0.975), mean = mean(repprop))
values_adults10


########

# Statistical analyses

## 2) Chi-squared tests to test for independence between sex, smolt age, and sea age.

# Import the smolt age data
adultssmolts_chi <- read.table(file="Data_Smoltsadults_TK.txt", 
                           header = TRUE, 
                           dec = ".")
#This dataset consists of smolts & adults

#Delete rows where SMOLT.AGE has no value (1 individual)
adultssmolts_chi <- subset(adultssmolts_chi, adultssmolts_chi$SMOLT.AGE != "") 

chisq.test(adultssmolts_chi$SEX, adultssmolts_chi$SMOLT.AGE)
#This is for all 482 individuals with smolt age defined


#Import sea age data (only adults)
adults_chi <- read.table(file="Data_Adults_TK.txt", 
                     header = TRUE, 
                     dec = ".")

chisq.test(adults_chi$SEX, adults_chi$SEA.AGE)
#This is for all 287 individuals with sea age defined


### Individuals with unassigned sex removed:

adultssmolts_chi_2 <- subset(adultssmolts_chi, adultssmolts_chi$SEX != "Unknown") 
# delete rows where SEX is NA

chisq.test(adultssmolts_chi_2$SEX, adultssmolts_chi_2$SMOLT.AGE)
#474 individuals with smolt age & sex defined

adults_chi_2 <- subset(adults_chi, adults_chi$SEX != "Unknown") 
# delete rows where SEX is NA

chisq.test(adults_chi_2$SEX, adults_chi_2$SEA.AGE)
#279 individuals with sex & sea age defined



## 3) Multinomial logistic regression

# To investigate whether there were differences in smolt age or sea age between 
# different parts of the river system, we performed multinomial logistic regression 
# using the nnet package in R (Venables and Ripley 2002), 
# with each individual's posterior mean of membership to the 'Upper' reporting group (PofZU here)
# as the explanatory variable. 

# Packages needed:

library(nnet)

#SMOLTS
#All smolt age data, including from smolts and adults (n = 482)

# Import the data
adultssmolts <- read.table(file="Data_Smoltsadults_TK.txt", 
                           header = TRUE, 
                           dec = ".")

adultssmolts <- subset(adultssmolts, adultssmolts$SMOLT.AGE != "") 
#Delete rows where SMOLT.AGE has no value

#First, choose the level of the outcome. Then, run the model using multinom. 
#This does not include p-value calculation for the regression coefficients, so 
#calculating p-values using Wald tests below (here z-tests).

#Here, reference = 2 year old smolts:
adultssmolts$SMOLT.AGE <- relevel(adultssmolts$SMOLT.AGE, ref = "2")
ref2 <- multinom(SMOLT.AGE ~ PofZU, data = adultssmolts)

summary(ref2)

# 2-tailed z test
zsmolts <- summary(ref2)$coefficients/summary(ref2)$standard.errors
zsmolts

# 2-tailed Wald z tests to test significance of coefficients
psmolts <- (1 - pnorm(abs(zsmolts), 0, 1)) * 2
psmolts


#Ref = 3 year old smolts:
adultssmolts$SMOLT.AGE <- relevel(adultssmolts$SMOLT.AGE, ref = "3")
ref3 <- multinom(SMOLT.AGE ~ PofZU, data = adultssmolts)

summary(ref3)

# 2-tailed z test
zsmolts <- summary(ref3)$coefficients/summary(ref3)$standard.errors
zsmolts

# 2-tailed Wald z tests to test significance of coefficients
psmolts <- (1 - pnorm(abs(zsmolts), 0, 1)) * 2
psmolts


#Ref = 4+ year old smolts:
adultssmolts$SMOLT.AGE <- relevel(adultssmolts$SMOLT.AGE, ref = "4+")
ref4 <- multinom(SMOLT.AGE ~ PofZU, data = adultssmolts)

summary(ref4)

# 2-tailed z test
zsmolts <- summary(ref4)$coefficients/summary(ref4)$standard.errors
zsmolts

# 2-tailed Wald z tests to test significance of coefficients
psmolts <- (1 - pnorm(abs(zsmolts), 0, 1)) * 2
psmolts



# ADULTS
# All sea age data, from adults only (n = 287)

# Import the data
adults <- read.table(file="Data_Adults_TK.txt", 
                     header = TRUE, 
                     dec = ".")


sum(is.na(adults$SEA.AGE))
#no NA

#Everything like above for the smolt age analyses
adults$SEA.AGE2 <- relevel(adults$SEA.AGE, ref = "1")
ref1 <- multinom(SEA.AGE2 ~ PofZU, data = adults)

summary(ref1)

# 2-tailed z test
z <- summary(ref1)$coefficients/summary(ref1)$standard.errors
z

# 2-tailed Wald z tests to test significance of coefficients
p <- (1 - pnorm(abs(z), 0, 1)) * 2
p


#Different references below
#Ref = 2SW
adults$SEA.AGE2 <- relevel(adults$SEA.AGE, ref = "2")
ref2 <- multinom(SEA.AGE2 ~ PofZU, data = adults)

summary(ref2)

# 2-tailed z test
z <- summary(ref2)$coefficients/summary(ref2)$standard.errors
z

# 2-tailed Wald z tests to test significance of coefficients
p <- (1 - pnorm(abs(z), 0, 1)) * 2
p


#Ref = 3SW
adults$SEA.AGE2 <- relevel(adults$SEA.AGE, ref = "3")
ref3 <- multinom(SEA.AGE2 ~ PofZU, data = adults)

summary(ref3)

# 2-tailed z test
z <- summary(ref3)$coefficients/summary(ref3)$standard.errors
z

# 2-tailed Wald z tests to test significance of coefficients
p <- (1 - pnorm(abs(z), 0, 1)) * 2
p


#Ref = 4-5SW
adults$SEA.AGE2 <- relevel(adults$SEA.AGE, ref = "4+")
ref4 <- multinom(SEA.AGE2 ~ PofZU, data = adults)

summary(ref4)

# 2-tailed z test
z <- summary(ref4)$coefficients/summary(ref4)$standard.errors
z

# 2-tailed Wald z tests to test significance of coefficients
p <- (1 - pnorm(abs(z), 0, 1)) * 2
p



## 4) Negative binomial GLM

# Negative binomial GLM to investigate the relationship of P(Upper) 
# (posterior mean of membership to the 'Upper' reporting group), 
# smolt age (smolts only), sea age (adults only), year (adults only), and sex (smolts and adults) 
# to seasonal migration timing.

# Package needed:

library(MASS)

# Smolts

# Import the data
smolts <- read.table(file="Data_Smolts_TK.txt", 
                     header = TRUE, 
                     dec = ".")
#Days for smolts are from 1 May onwards
#E.g. May 14 is 14 days etc.

#Looking at what affects catch date (DAY) during the season
#Covariates: SEX, SMOLT.AGE, PofZU

#Performing glm with negative binomial distribution
smolts_glm_nb1 <- glm.nb(DAY ~ PofZU + SEX + SMOLT.AGE, 
                data = smolts)

summary(smolts_glm_nb1)

#Using stepwise reduction to simplify the model
step(smolts_glm_nb1)

#Best model based on AIC:
#Call:  glm.nb(formula = DAY ~ PofZU, data = smolts, init.theta = 10.51202995, 
#              link = log)

#The best model to use includes only PofZU:

smolts_glm_nb2 <- glm.nb(DAY ~ PofZU, 
                data = smolts)

summary(smolts_glm_nb2)

print(summary(smolts_glm_nb2), digits = 2, signif.stars=TRUE)

#Call: glm.nb(formula = DAY ~ PofZU, data = smolts, init.theta = 10.51202934, 
#link = log)


####
# Code below is for creating Fig. 6a
# Sketching the model fit

# Package needed:

library(plyr)

# Creating a grid of covariate values
MyData <- ddply(smolts, 
                .(SMOLT.AGE), 
                summarize,
                PofZU = seq(min(PofZU), 
                            max(PofZU), 
                            length = 25))

#Getting predicted values for the covariate values
P <- predict(smolts_glm_nb2, newdata = MyData, se = TRUE, type = "link")

# Adding fitted values and confidence bands
MyData$mu    <- exp(P$fit)                 #Fitted values
MyData$selow <- exp(P$fit - 1.96 * P$se.fit)  #lower bound
MyData$seup  <- exp(P$fit + 1.96 * P$se.fit)  #upper bound
head(MyData)

# Plotting it
# This produces Fig. 6a below

smoltlabels = c("2" = "2 years old", "3" = "3 years old", "4+" = "4-5 years old")

p2 <- ggplot()
p2 <- p2 + geom_point(data = smolts, 
                      aes(y = DAY, x = PofZU),
                      shape = 16, 
                      size = 3,
                      alpha = 0.7,
                      col="grey50")
p2 <- p2 + xlab("P(Upper)") + ylab("Capture date")
p2 <- p2 + theme(text = element_text(size=15)) + theme_classic() + ggtitle("Outmigrating smolts") 
p2 <- p2 + theme(axis.title.x = element_text(size=14))
p2 <- p2 + theme(axis.title.y = element_text(size=14))
p2 <- p2 + theme(legend.position = "none")
p2 <- p2 + geom_line(data = MyData, 
                     aes(x = PofZU, 
                         y = mu), colour = "black")

p2 <- p2 + geom_ribbon(data = MyData, 
                       aes(x = PofZU, 
                           ymax = seup, 
                           ymin = selow,
                           alpha=0.3), fill="aquamarine3")

smoltplot_nbglm <- p2 + facet_grid(SMOLT.AGE ~ ., scales = "fixed", labeller=labeller(SMOLT.AGE = smoltlabels)) 

smoltplot_nbglm


####

# Negative binomial GLM for adults

# Import the data
adults <- read.table(file="Data_Adults_TK.txt", 
                     header = TRUE, 
                     dec = ".")
#The dates are days from June 1 onwards
#E.g. June 4 is Day 4 etc.

# Convert YEAR into a factor
adults$fYEAR <- factor(adults$YEAR,
                       levels = c(2009, 2010),
                       labels = c("2009", "2010"))

str(adults)

colSums(is.na(adults)) 
#This reports the total number of missing values for each variable

adults <- subset(adults, adults$SEX != "Unknown") 
#Delete rows where SEX is unknown

#Looking at what affects catch date during the season (response variable).
#Covariates are fYEAR, SEX, SEA.AGE, PofZU.

#Perform glm with negative binomial distribution
adults_glm_nb1 <- glm.nb(DAY ~ PofZU + SEA.AGE + fYEAR + SEX, 
                data = adults)

summary(adults_glm_nb1)

#Using stepwise reduction to simplify the model
step(adults_glm_nb1)

#Best model based on AIC:

#Call: glm.nb(formula = DAY ~ PofZU + SEA.AGE + fYEAR, data = adults, 
#init.theta = 4.681542316, link = log)

#The best model to use includes PofZU, SEA.AGE & fYEAR:

adults_glm_nb2 <- glm.nb(DAY ~ PofZU + SEA.AGE + fYEAR, 
                data = adults)

summary(adults_glm_nb2)

print(summary(adults_glm_nb2), digits = 2, signif.stars=TRUE)

#Call: glm.nb(formula = DAY ~ PofZU + SEA.AGE + fYEAR, data = adults, 
#init.theta = 4.681542276, link = log)


#######
# Code below is for creating Fig. 6b

# Sketching the model fit

# Creating a grid of covariate values
MyData2 <- ddply(adults, 
                .(fYEAR, SEA.AGE), 
                summarize,
                PofZU = seq(min(PofZU), 
                            max(PofZU), 
                            length = 25))

#Getting predicted values for the covariate values
P <- predict(adults_glm_nb2, newdata = MyData2, se = TRUE, type = "link")

# Adding fitted values and confidence bands
MyData2$mu    <- exp(P$fit)                 #Fitted values
MyData2$selow <- exp(P$fit - 1.96 * P$se.fit)  #lower bound
MyData2$seup  <- exp(P$fit + 1.96 * P$se.fit)  #upper bound
head(MyData2)

# Plotting it
# Code below produces Fig. 6b

col = c("Female"="#E66100", "Male" = "#5D3A9B", "Unknown" = "gray50")
labels = c("1" = "1 sea winter", "2" = "2 sea winters", "3" = "3 sea winters", 
           "4+" = "4-5 sea winters", "PS" = "Repeat spawners")

p2 <- ggplot()
p2 <- p2 + geom_point(data = adults, 
                      aes(y = DAY, x = PofZU, col=SEA.AGE),
                      shape = 16, 
                      size = 3,
                      alpha=0.7)
p2 <- p2 + xlab("P(Upper)") + ylab("Capture date")
p2 <- p2 + theme(text = element_text(size=15, face="bold")) + theme_classic() 
p2 <- p2 + ggtitle("Returning adults") 
p2 <- p2 + theme(axis.title.x = element_text(size=14))
p2 <- p2 + theme(axis.title.y = element_text(size=14))
p2 <- p2 + geom_line(data = MyData2, 
                     aes(x = PofZU, 
                         y = mu,
                         group = SEA.AGE,
                         col = SEA.AGE))

p2 <- p2 + geom_ribbon(data = MyData2, 
                       aes(x = PofZU, 
                           ymax = seup, 
                           ymin = selow,
                           group = SEA.AGE,
                           fill = SEA.AGE),
                       alpha = 0.3)

p2 <- p2 + facet_grid(. ~ fYEAR, scales = "fixed")
p2 <- p2 + guides(fill=guide_legend("Sea age")) + guides(color=guide_legend("Sea age"))
adultplot_nbglm <- p2 + scale_color_discrete(labels = c("1SW", "2SW", "3SW", "4-5SW", "RS"))

adultplot_nbglm
